Changelog
=========

1.2.0b1 (2025-06-17)
--------------------
- Add support for Python 3.14
- Add support for PyPy 3.11
- Drop support for Python 3.9 (due to compatibility issues).
- Drop support for PyPy 3.9
- | Drop support for Oracle Java 1.8 (jdk, jre) due to licensing issues
  | and the end of support from Oracle.
- Update readthedocs's python to version 3.13
- Update tox's base_python to version 3.13
- The distribution is now created using 'build' instead of 'setuptools'.
- Copyright year update.
- Setup (dependencies) update.

1.1.0b6 (2024-12-01)
--------------------
- Fixes for embedded python.
- Java 17 is now the primary build/test environment.
- Add support for Python 3.13
- Drop support for Python 3.8
- jni.c and pvm.c (useful for embedded python apps) have been added.
- Unittest have been performed for much more JVMs.
- Tox configuration is now in native (toml) format.
- Setup fixes.
- Setup (dependencies) update.

1.0.0b22 (2024-01-26)
---------------------
- Tox configuration has been moved to pyproject.toml
- Setup update (now based on tox >= 4.0).
- Add support for Python 3.10, 3.11 and 3.12
- Drop support for Python 3.7
- Add support for PyPy 3.9 and 3.10
- Copyright year update.

1.0.0b20 (2022-01-29)
---------------------
- Drop support for Python 3.6
- Setup update.

1.0.0b18 (2021-10-13)
---------------------
- dll_path argument of load() can also be type os.PathLike.
- Copyright year update.
- Setup update.

1.0.0b17 (2020-11-10)
---------------------
- Add support for Python 3.9
- General update, improvements and cleanup.
- Setup update and improvements.
- Fixed docs setup.

1.0.0b7 (2020-03-08)
--------------------
- Drop support for Python2
- Update of license info.
- Setup update.

1.0.0b4 (2019-07-10)
--------------------
- Last release for Python2

1.0.0b3 (2018-05-22)
--------------------
- Update of the required setuptools version.

1.0.0b2 (2018-02-26)
--------------------
- Improvement and simplification of setup and packaging.

1.0.0b1 (2017-11-18)
--------------------
- First 'official' version.

0.1.1 (2005-10-05)
------------------
- Initial version.
